@@ -1,5 +1,5 @@
 """Utilities for getting postgreSQL related metrics."""
-import commands
+import subprocess
 
 
 def get_database_size(db_user, db_name, localhost=False):
@@ -15,6 +15,5 @@ def get_database_size(db_user, db_name, localhost=False):
         localhost_part = '-h localhost '
     cmd = 'psql {0}-U {1} -c "select pg_database_size(\'{2}\');"'.format(
         localhost_part, db_user, db_name)
-    total = commands.getoutput(cmd).split()[2]
-    total = int(total)
-    return total
+    total = subprocess.getoutput(cmd).split()[2]
+    return int(total)
